@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6585 $
-## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
+## |  File version: $Revision: 6801 $
+## |  Last changed: $Date: 2023-02-06 15:29:57 +0100 (Mon, 06 Feb 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -267,8 +267,11 @@ TrialDesignPlan <- setRefClass("TrialDesignPlan",
 #'
 as.data.frame.TrialDesignPlan <- function(x, row.names = NULL,
         optional = FALSE, niceColumnNamesEnabled = FALSE, includeAllParameters = FALSE, ...) {
-    return(.getAsDataFrame(parameterSet = x, parameterNames = NULL,
-        niceColumnNamesEnabled = niceColumnNamesEnabled, includeAllParameters = includeAllParameters
+    return(.getAsDataFrame(
+        parameterSet = x, 
+        parameterNames = NULL,
+        niceColumnNamesEnabled = niceColumnNamesEnabled, 
+        includeAllParameters = includeAllParameters
     ))
 }
 
@@ -2050,7 +2053,7 @@ TrialDesignPlanSurvival <- setRefClass("TrialDesignPlanSurvival",
 #' Generic function to plot all kinds of trial design plans.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' if (require(ggplot2)) plot(getSampleSizeMeans())
 #' }
 #'
